@@ -23,7 +23,8 @@ def get_option_parser():
         '--engine',
         dest='engine',
         help=('Database engine to test, one of '
-              '[sqlite, postgres, mysql, mysqlconnector, apsw, sqlcipher]'))
+              '[sqlite, postgres, mysql, mysqlconnector, apsw, sqlcipher,'
+              ' cockroachdb]'))
     basic.add_option('-v', '--verbosity', dest='verbosity', default=1,
                      type='int', help='Verbosity of output')
     basic.add_option('-f', '--failfast', action='store_true', default=False,
@@ -41,7 +42,13 @@ def get_option_parser():
             ('host', 'localhost', os.environ.get('PGHOST', '')),
             ('port', '5432', ''),
             ('user', 'postgres', os.environ.get('PGUSER', '')),
-            ('password', 'blank', os.environ.get('PGPASSWORD', '')))))
+            ('password', 'blank', os.environ.get('PGPASSWORD', '')))),
+        ('CockroachDB', 'CRDB', (
+            # param  default disp default val
+            ('host', 'localhost', 'localhost'),
+            ('port', '26257', ''),
+            ('user', 'root', 'root'),
+            ('password', 'blank', ''))))
     for name, prefix, param_list in db_param_map:
         group = optparse.OptionGroup(parser, '%s connection options' % name)
         for param, default_disp, default_val in param_list:
@@ -75,7 +82,7 @@ if __name__ == '__main__':
     if options.engine:
         os.environ['PEEWEE_TEST_BACKEND'] = options.engine
 
-    for db in ('mysql', 'psql'):
+    for db in ('mysql', 'psql', 'crdb'):
         for key in ('host', 'port', 'user', 'password'):
             att_name = '_'.join((db, key))
             value = getattr(options, att_name, None)
